@@ -4,7 +4,9 @@ import psycopg2.sql as sql
 from Connector import Connector
 from error_handlers import log_error, retry_log_error
 from qrlogging import logger
+from threading import Lock
 
+lock = Lock()
 
 class PostgresConnector(Connector):
     def __init__(self, db, user, password, host='localhost', port=5432):
@@ -30,8 +32,10 @@ class PostgresConnector(Connector):
             request = request.format(*identifiers)
 
         logger.warning('POSTGRES EXECUTE: %s with literals %s', request.as_string(self.cursor), literals)
-        self.cursor.execute(request, literals)
-        return self.extract_result(result)
+        with lock:
+            self.cursor.execute(request, literals)
+            data = self.extract_result(result)
+        return data
 
     def extract_result(self, result):
         if result == 'all':
