@@ -10,8 +10,6 @@ class DataFormatter:
     # result type -> 'all', 'one'
     @log_error
     def format_data(self, data, used_fields, result_type):
-        logger.warning("Formatting:\n\tdata: %s\n\tused_fields: %s\n\tresult: %s", data,
-                    used_fields, result_type)
         if result_type is None or data is None:
             return None
 
